OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Auto detect failed. Please use manual mode.",
    "Updating account failed: " : "Updating account failed: ",
    "Creating account failed: " : "Creating account failed: ",
    "Mail" : "Mail",
    "Name" : "Name",
    "Mail Address" : "Mail Address",
    "Password" : "Password",
    "IMAP Host" : "IMAP Host",
    "None" : "None",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP User",
    "IMAP Password" : "IMAP Password",
    "SMTP Host" : "SMTP Host",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP User",
    "SMTP Password" : "SMTP Password",
    "Save" : "Save",
    "Connect" : "Connect",
    "Add mail account" : "Add mail account",
    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
    "Select account" : "Select account",
    "Subject" : "Subject",
    "Upload attachment" : "Upload attachment",
    "Add attachment from Files" : "Add attachment from Files",
    "Sending …" : "Sending…",
    "Go back" : "Go back",
    "Retry" : "Retry",
    "Message sent!" : "Message sent!",
    "Send" : "Send",
    "Choose a file to add as attachment" : "Choose a file to add as attachment",
    "No messages in this folder" : "No messages in this folder",
    "Mark read" : "Mark read",
    "Unselect" : "Unselect",
    "Select" : "Select",
    "Move" : "Move",
    "Delete" : "Delete",
    "Choose" : "Choose",
    "Important" : "Important",
    "Favorites" : "Favourites",
    "Other" : "Other",
    "Attachments" : "Attachments",
    "Import into calendar" : "Import into calendar",
    "Download attachment" : "Download attachment",
    "Save to Files" : "Save to Files",
    "Unnamed" : "Unnamed",
    "Choose a folder to store the attachment in" : "Choose a folder to store the attachment in",
    "Save all to Files" : "Save all to Files",
    "The images have been blocked to protect your privacy." : "The images have been blocked to protect your privacy.",
    "Show images from this sender" : "Show images from this sender",
    "New message" : "New message",
    "Settings" : "Settings",
    "Quota" : "Quota",
    "Add folder" : "Add folder",
    "Saving" : "Saving",
    "Remove account" : "Remove account",
    "Cancel" : "Cancel",
    "Show all folders" : "Show all folders",
    "Collapse folders" : "Collapse folders",
    "Mark all as read" : "Mark all as read",
    "Clear cache" : "Clear cache",
    "Delete folder" : "Delete folder",
    "Not found" : "Not found",
    "Signature" : "Signature",
    "Reply" : "Reply",
    "Forward" : "Forward",
    "General" : "General",
    "User" : "User",
    "Host" : "Host",
    "Port" : "Port",
    "Change name" : "Change name",
    "Keyboard shortcut" : "Keyboard shortcut",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
    "Compose new message" : "Compose new message",
    "Newer message" : "Newer message",
    "Older message" : "Older message",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle unread",
    "Search" : "Search",
    "Refresh" : "Refresh",
    "Connect your mail account" : "Connect your mail account",
    "All" : "All",
    "Archive" : "Archive",
    "Drafts" : "Drafts",
    "All inboxes" : "All inboxes",
    "Inbox" : "Inbox",
    "Junk" : "Junk",
    "Sent" : "Sent",
    "Trash" : "Trash",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Could not load {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "There was a problem loading {tag}{name}{endtag}",
    "Could not load your message" : "Could not load your message",
    "Could not load the desired message" : "Could not load the desired message",
    "Could not load the message" : "Could not load the message",
    "Error loading message" : "Error loading message",
    "Forwarding to %s" : "Forwarding to %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Click here if you are not automatically redirected within the next few seconds.",
    "Redirect" : "Redirect",
    "The link leads to %s" : "The link leads to %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continue to %s"
},
"nplurals=2; plural=(n != 1);");
